@@ -3,28 +3,17 @@ from typing import Dict, Optional, List
 
 
 @dataclass
-class Config:
-    broker_type: str
-
-
-@dataclass
-class KafkaConfig(Config):
+class KafkaConfig:
     bootstrap_servers: List[str]
     topic: str
     client_id: Optional[str] = None
 
 
-@dataclass
-class SimpleConfig(Config):
-    pass
-
 
 class ConfigFactory:
     @staticmethod
     def create_config(config_type: str, **kwargs):
-        if config_type == "kafka":
+        if config_type == "KAFKA":
             return KafkaConfig(**kwargs)
-        elif config_type == "simple":
-            return SimpleConfig(**kwargs)
         else:
             raise ValueError(f"Unknown config type: {config_type}")
\ No newline at end of file
