@@ -11,9 +11,11 @@ class LogInfo:
     """
     ip_address: str
     user_id: Optional[str]
+    username: Optional[str]
     request_time: str
     action: str
     request_data: Dict[str, Any]
+    headers: Dict[str, Any]
     
     def to_dict(self) -> Dict[str, Any]:
         """Convert the log info to a dictionary"""
